The ``jicbioimage.core`` Python package
=======================================

.. image:: https://badge.fury.io/py/jicbioimage.core.svg
   :target: http://badge.fury.io/py/jicbioimage.core
   :alt: PyPi package

.. image:: https://travis-ci.org/JIC-CSB/jicbioimage.core.svg?branch=master
   :target: https://travis-ci.org/JIC-CSB/jicbioimage.core
   :alt: Travis CI build status (Linux)

.. image:: https://ci.appveyor.com/api/projects/status/xe9a8alhmhrm0qi7/branch/master?svg=true
   :target: https://ci.appveyor.com/project/tjelvar-olsson/jicbioimage-core
   :alt: AppVeyor CI build status (Windows)

.. image:: https://codecov.io/github/JIC-CSB/jicbioimage.core/coverage.svg?branch=master
   :target: https://codecov.io/github/JIC-CSB/jicbioimage.core?branch=master
   :alt: Code Coverage

.. image:: https://readthedocs.org/projects/jicbioimagecore/badge/?version=latest
   :target: https://readthedocs.org/projects/jicbioimagecore?badge=latest
   :alt: Documentation Status

The ``jicbioimage.core`` Python package provides the core functionality of the
``jicbioimage`` namespace package.

- Documentation: http://jicbioimagecore.readthedocs.io
- GitHub: https://github.com/JIC-CSB/jicbioimage.core
- PyPI: https://pypi.python.org/pypi/jicbioimage.core
- Free software: MIT License

Features
--------

- Built in functionality for working with microscopy data
- Automatic generation of audit trails
- IPython integration
- Cross-platform: Linux, Mac and Windows are all supported
- Works with Python 2.7, 3.3 and 3.4

Related packages
----------------

``jicbioimage``
^^^^^^^^^^^^^^^

- Documentation: http://jicbioimage.readthedocs.io
- GitHub: https://github.com/JIC-CSB/jicbioimage

``jicbioimage.transform``
^^^^^^^^^^^^^^^^^^^^^^^^^

- Documentation: http://jicbioimagetransform.readthedocs.io
- GitHub: https://github.com/JIC-CSB/jicbioimage.transform

``jicbioimage.segment``
^^^^^^^^^^^^^^^^^^^^^^^

- Documentation: http://jicbioimagesegment.readthedocs.io
- GitHub: https://github.com/JIC-CSB/jicbioimage.segment

``jicbioimage.illustrate``
^^^^^^^^^^^^^^^^^^^^^^^^^^

- Documentation: http://jicbioimageillustrate.readthedocs.io
- GitHub: https://github.com/JIC-CSB/jicbioimage.illustrate
